/*
 *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
 *  m_fixts.c: Allows Admins to force TS1 onto a channel.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  m_fixts.c - (C) Alan 'alz' Milford, 8th May 2003.
 *
 *  Usage: 
 * 
 *  /makets1 #channel - Makes #channel's TS 1.
 *
 *  Note: This module is designed for TESTING purposes only, it has no
 *        use on a network other than to break things.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 */

#include "stdinc.h"
#include "tools.h"
#include "handlers.h"
#include "channel.h"
#include "channel_mode.h"
#include "client.h"
#include "ircd.h"
#include "numeric.h"
#include "s_log.h"
#include "s_serv.h"
#include "send.h"
#include "whowas.h"
#include "irc_string.h"
#include "hash.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"
#include "vchannel.h"
#include "list.h"

static void ms_smakets1(struct Client *, struct Client *, int, char **);
static void mo_makets1(struct Client *, struct Client *, int, char**);

struct Message makets1_msgtab = {
  "MAKETS1", 0, 0, 2, 0, MFLG_SLOW, 0,
  {m_unregistered, m_not_oper, m_ignore, mo_makets1}
};

struct Message smakets1_msgtab = {
  "SMAKETS1", 0, 0, 0, 0, MFLG_SLOW, 0,
  {m_unregistered, m_not_oper, ms_smakets1, m_ignore}
};


#ifndef STATIC_MODULES

void
_modinit(void)
{
  mod_add_cmd(&makets1_msgtab);
  mod_add_cmd(&smakets1_msgtab);;
}

void
_moddeinit(void)
{
  mod_del_cmd(&makets1_msgtab);
  mod_del_cmd(&smakets1_msgtab);
}

const char *_version = "1.0";
#endif


/*
** mo_makets1
**      parv[0] = sender prefix
**      parv[1] = channel
**      parv[2] = ts to change to
*/
static void mo_makets1(struct Client *client_p, struct Client *source_p,
                        int parc, char *parv[])
{
  struct Channel *chptr;
  int newts = 0;

  /* admins only */
  if (!IsOperAdmin(source_p))
    {
      sendto_one(source_p, ":%s NOTICE %s :You have no A flag", me.name, parv[0]);
      return;
    }

  chptr= hash_find_channel(parv[1]);

  if( chptr == NULL )
    {
      sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
		 me.name, parv[0], parv[1]);
      return;
    }

  newts = atoi("1");
  chptr->channelts = newts;
  sendto_server(client_p, source_p, chptr, NOCAPS, NOCAPS,
                        LL_ICLIENT,
                        ":%s SMAKETS1 %s %d %s!%s@%s",
                        me.name, parv[1], newts, source_p->name, source_p->username,
              source_p->host);
   sendto_wallops_flags(FLAGS_WALLOP, &me,
              "Channel %s now TS%d [%s!%s@%s]",
              parv[1], newts, source_p->name, source_p->username,
              source_p->host);
}

/*
 * ms_smakets1
 *
 * inputs	-
 * output	- none
 * side effects	- handles remote ts fixes
 */

static void 
ms_smakets1(struct Client *client_p,
	struct Client *source_p,
	int parc,
	char *parv[])
{
  struct Channel *chptr;
  int newts = 0;
 chptr= hash_find_channel(parv[1]);
if ( chptr != NULL )
{
newts = atoi(parv[2]);
  chptr->channelts = newts;

  sendto_wallops_flags(FLAGS_WALLOP, &me,
              "Channel %s now TS%d [%s]",
              parv[1], newts, parv[3]);
}
}

